==> v1.4.1.3258.tar.gz: prowlarr/frontend/src/Styles/Themes/dark.js <==
const prowlarrOrange = '#e66000';

module.exports = {
  textColor: '#ccc',
  defaultColor: '#ccc',
  disabledColor: '#999',
  dimColor: '#555',
  black: '#000',
  white: '#fff',
  primaryColor: '#5d9cec',
  selectedColor: '#f9be03',
  successColor: '#00853d',
  dangerColor: '#f05050',
  warningColor: '#ffa500',
  infoColor: '#5d9cec',
  purple: '#7a43b6',
  prowlarrOrange,
  helpTextColor: '#909293',
  darkGray: '#888',
  gray: '#adadad',

  // Theme Colors

  themeBlue: prowlarrOrange,
  themeRed: '#c4273c',
  themeDarkColor: '#595959',
  themeLightColor: prowlarrOrange,
  pageBackground: '#202020',
  pageFooterBackgroud: 'rgba(0, 0, 0, .25)',

  torrentColor: '#00853d',
  usenetColor: '#17b1d9',

  // Labels
  inverseLabelColor: '#ddd',
  inverseLabelTextColor: prowlarrOrange,

  // Links
  defaultLinkHoverColor: '#fff',
  linkColor: '#rgb(230, 96, 0)',
  linkHoverColor: '#rgb(230, 96, 0, .8)',

  // Header
  pageHeaderBackgroundColor: '#2a2a2a',

  // Sidebar

  sidebarColor: '#e1e2e3',
  sidebarBackgroundColor: '#2a2a2a',
  sidebarActiveBackgroundColor: '#333333',

  // Toolbar
  toolbarColor: '#e1e2e3',
  toolbarBackgroundColor: '#262626',
  toolbarMenuItemBackgroundColor: '#333',
  toolbarMenuItemHoverBackgroundColor: '#414141',
  toolbarLabelColor: '#e1e2e3',

  // Accents
  borderColor: '#e5e5e5',
  inputBorderColor: '#dde6e9',
  inputBoxShadowColor: 'rgba(0, 0, 0, 0.075)',
  inputFocusBorderColor: '#66afe9',
  inputFocusBoxShadowColor: 'rgba(102, 175, 233, 0.6)',
  inputErrorBorderColor: '#f05050',
  inputErrorBoxShadowColor: 'rgba(240, 80, 80, 0.6)',
  inputWarningBorderColor: '#ffa500',
  inputWarningBoxShadowColor: 'rgba(255, 165, 0, 0.6)',
  colorImpairedGradient: '#ffffff',
  colorImpairedGradientDark: '#f4f5f6',

  //
  // Buttons

  defaultButtonTextColor: '#eee',
  defaultButtonBackgroundColor: '#333',
  defaultBorderColor: '#eaeaea',
  defaultHoverBackgroundColor: '#444',
  defaultHoverBorderColor: '#d6d6d6',

  primaryBackgroundColor: '#5d9cec',
  primaryBorderColor: '#5899eb',
  primaryHoverBackgroundColor: '#4b91ea',
  primaryHoverBorderColor: '#3483e7',

  successBackgroundColor: '#27c24c',
  successBorderColor: '#26be4a',
  successHoverBackgroundColor: '#24b145',
  successHoverBorderColor: '#1f9c3d',

  warningBackgroundColor: '#ff902b',
  warningBorderColor: '#ff8d26',
  warningHoverBackgroundColor: '#ff8517',
  warningHoverBorderColor: '#fc7800',

  dangerBackgroundColor: '#f05050',
  dangerBorderColor: '#f04b4b',
  dangerHoverBackgroundColor: '#ee3d3d',
  dangerHoverBorderColor: '#ec2626',

  iconButtonDisabledColor: '#7a7a7a',
  iconButtonHoverColor: '#666',
  iconButtonHoverLightColor: '#ccc',

  //
  // Modal

  modalBackdropBackgroundColor: 'rgba(0, 0, 0, 0.6)',
  modalBackgroundColor: '#2a2a2a',
  modalCloseButtonHoverColor: '#888',

  //
  // Menu
  menuItemColor: '#e1e2e3',
  menuItemHoverColor: '#e66000',
  menuItemHoverBackgroundColor: '#606060',

  //
  // Toolbar

  toobarButtonHoverColor: '#e66000',
  toobarButtonSelectedColor: '#e66000',

  //
  // Scroller

  scrollbarBackgroundColor: '#707070',
  scrollbarHoverBackgroundColor: '#606060',

  //
  // Card

  cardBackgroundColor: '#333333',
  cardShadowColor: '#111',
  cardAlternateBackgroundColor: '#333333',
  cardCenterBackgroundColor: '#2a2a2a',

  //
  // Alert

  alertDangerBorderColor: '#a94442',
  alertDangerBackgroundColor: 'rgba(255,0,0,0.1)',
  alertDangerColor: '#ccc',

  alertInfoBorderColor: '#31708f',
  alertInfoBackgroundColor: 'rgba(0,0,255,0.1)',
  alertInfoColor: '#ccc',

  alertSuccessBorderColor: '#3c763d',
  alertSuccessBackgroundColor: 'rgba(0,255,0,0.1)',
  alertSuccessColor: '#ccc',

  alertWarningBorderColor: '#8a6d3b',
  alertWarningBackgroundColor: 'rgba(255,255,0,0.1)',
  alertWarningColor: '#ccc',

  //
  // Form

  inputBackgroundColor: '#333',
  inputReadOnlyBackgroundColor: '#222',
  inputHoverBackgroundColor: 'rgba(255, 255, 255, 0.20)',
  inputSelectedBackgroundColor: 'rgba(255, 255, 255, 0.05)',
  advancedFormLabelColor: '#ff902b',
  disabledCheckInputColor: '#ddd',
  disabledInputColor: '#808080',

  //
  // Popover

  popoverTitleBackgroundColor: '#424242',
  popoverTitleBorderColor: '#2a2a2a',
  popoverBodyBackgroundColor: '#2a2a2a',
  popoverShadowColor: 'rgba(0, 0, 0, 0.2)',
  popoverArrowBorderColor: '#2a2a2a',

  popoverTitleBackgroundInverseColor: '#595959',
  popoverTitleBorderInverseColor: '#707070',
  popoverShadowInverseColor: 'rgba(0, 0, 0, 0.2)',
  popoverArrowBorderInverseColor: 'rgba(58, 63, 81, 0.75)',

  //
  // Table

  tableRowHoverBackgroundColor: 'rgba(255, 255, 255, 0.08)',

  //
  // Charts

  failedColors: ['#ffbeb2', '#feb4a6', '#fdab9b', '#fca290', '#fb9984', '#fa8f79', '#f9856e', '#f77b66', '#f5715d', '#f36754', '#f05c4d', '#ec5049', '#e74545', '#e13b42', '#da323f', '#d3293d', '#ca223c', '#c11a3b', '#b8163a', '#ae123a'],
  chartColorsDiversified: ['#90caf9', '#f4d166', '#ff8a65', '#ce93d8', '#80cba9', '#ffab91', '#8097ea', '#bcaaa4', '#a57583', '#e4e498', '#9e96af', '#c6ab81', '#6972c6', '#619fc6', '#81ad81', '#f48fb1', '#82afca', '#b5b071', '#8b959b', '#7ec0b4'],
  chartColors: ['#f4d166', '#f6c760', '#f8bc58', '#f8b252', '#f7a84a', '#f69e41', '#f49538', '#f38b2f', '#f28026', '#f0751e', '#eb6c1c', '#e4641e', '#de5d1f', '#d75521', '#cf4f22', '#c64a22', '#bc4623', '#b24223', '#a83e24', '#9e3a26']
};

==> v1.5.2.3484.tar.gz: prowlarr/frontend/src/Styles/Themes/dark.js <==
const prowlarrOrange = '#e66000';

module.exports = {
  textColor: '#ccc',
  defaultColor: '#ccc',
  disabledColor: '#999',
  dimColor: '#555',
  black: '#000',
  white: '#fff',
  primaryColor: '#5d9cec',
  selectedColor: '#f9be03',
  successColor: '#00853d',
  dangerColor: '#f05050',
  warningColor: '#ffa500',
  infoColor: '#5d9cec',
  purple: '#7a43b6',
  prowlarrOrange,
  helpTextColor: '#909293',
  darkGray: '#888',
  gray: '#adadad',

  // Theme Colors

  themeBlue: prowlarrOrange,
  themeRed: '#c4273c',
  themeDarkColor: '#595959',
  themeLightColor: prowlarrOrange,
  pageBackground: '#202020',
  pageFooterBackgroud: 'rgba(0, 0, 0, .25)',

  torrentColor: '#00853d',
  usenetColor: '#17b1d9',

  // Labels
  inverseLabelColor: '#ddd',
  inverseLabelTextColor: prowlarrOrange,

  // Links
  defaultLinkHoverColor: '#fff',
  linkColor: '#rgb(230, 96, 0)',
  linkHoverColor: '#rgb(230, 96, 0, .8)',

  // Header
  pageHeaderBackgroundColor: '#2a2a2a',

  // Sidebar

  sidebarColor: '#e1e2e3',
  sidebarBackgroundColor: '#2a2a2a',
  sidebarActiveBackgroundColor: '#333333',

  // Toolbar
  toolbarColor: '#e1e2e3',
  toolbarBackgroundColor: '#262626',
  toolbarMenuItemBackgroundColor: '#333',
  toolbarMenuItemHoverBackgroundColor: '#414141',
  toolbarLabelColor: '#e1e2e3',

  // Accents
  borderColor: '#e5e5e5',
  inputBorderColor: '#dde6e9',
  inputBoxShadowColor: 'rgba(0, 0, 0, 0.075)',
  inputFocusBorderColor: '#66afe9',
  inputFocusBoxShadowColor: 'rgba(102, 175, 233, 0.6)',
  inputErrorBorderColor: '#f05050',
  inputErrorBoxShadowColor: 'rgba(240, 80, 80, 0.6)',
  inputWarningBorderColor: '#ffa500',
  inputWarningBoxShadowColor: 'rgba(255, 165, 0, 0.6)',
  colorImpairedGradient: '#ffffff',
  colorImpairedGradientDark: '#f4f5f6',

  //
  // Buttons

  defaultButtonTextColor: '#eee',
  defaultButtonBackgroundColor: '#333',
  defaultBorderColor: '#393f45',
  defaultHoverBackgroundColor: '#444',
  defaultHoverBorderColor: '#5a6265',

  primaryBackgroundColor: '#5d9cec',
  primaryBorderColor: '#5899eb',
  primaryHoverBackgroundColor: '#4b91ea',
  primaryHoverBorderColor: '#3483e7',

  successBackgroundColor: '#27c24c',
  successBorderColor: '#26be4a',
  successHoverBackgroundColor: '#24b145',
  successHoverBorderColor: '#1f9c3d',

  warningBackgroundColor: '#ff902b',
  warningBorderColor: '#ff8d26',
  warningHoverBackgroundColor: '#ff8517',
  warningHoverBorderColor: '#fc7800',

  dangerBackgroundColor: '#f05050',
  dangerBorderColor: '#f04b4b',
  dangerHoverBackgroundColor: '#ee3d3d',
  dangerHoverBorderColor: '#ec2626',

  iconButtonDisabledColor: '#7a7a7a',
  iconButtonHoverColor: '#666',
  iconButtonHoverLightColor: '#ccc',

  //
  // Modal

  modalBackdropBackgroundColor: 'rgba(0, 0, 0, 0.6)',
  modalBackgroundColor: '#2a2a2a',
  modalCloseButtonHoverColor: '#888',

  //
  // Menu
  menuItemColor: '#e1e2e3',
  menuItemHoverColor: '#e66000',
  menuItemHoverBackgroundColor: '#606060',

  //
  // Toolbar

  toobarButtonHoverColor: '#e66000',
  toobarButtonSelectedColor: '#e66000',

  //
  // Scroller

  scrollbarBackgroundColor: '#707070',
  scrollbarHoverBackgroundColor: '#606060',

  //
  // Card

  cardBackgroundColor: '#333333',
  cardShadowColor: '#111',
  cardAlternateBackgroundColor: '#333333',
  cardCenterBackgroundColor: '#2a2a2a',

  //
  // Alert

  alertDangerBorderColor: '#a94442',
  alertDangerBackgroundColor: 'rgba(255,0,0,0.1)',
  alertDangerColor: '#ccc',

  alertInfoBorderColor: '#31708f',
  alertInfoBackgroundColor: 'rgba(0,0,255,0.1)',
  alertInfoColor: '#ccc',

  alertSuccessBorderColor: '#3c763d',
  alertSuccessBackgroundColor: 'rgba(0,255,0,0.1)',
  alertSuccessColor: '#ccc',

  alertWarningBorderColor: '#8a6d3b',
  alertWarningBackgroundColor: 'rgba(255,255,0,0.1)',
  alertWarningColor: '#ccc',

  //
  // Form

  inputBackgroundColor: '#333',
  inputReadOnlyBackgroundColor: '#222',
  inputHoverBackgroundColor: 'rgba(255, 255, 255, 0.20)',
  inputSelectedBackgroundColor: 'rgba(255, 255, 255, 0.05)',
  advancedFormLabelColor: '#ff902b',
  disabledCheckInputColor: '#ddd',
  disabledInputColor: '#808080',

  //
  // Popover

  popoverTitleBackgroundColor: '#424242',
  popoverTitleBorderColor: '#2a2a2a',
  popoverBodyBackgroundColor: '#2a2a2a',
  popoverShadowColor: 'rgba(0, 0, 0, 0.2)',
  popoverArrowBorderColor: '#2a2a2a',

  popoverTitleBackgroundInverseColor: '#595959',
  popoverTitleBorderInverseColor: '#707070',
  popoverShadowInverseColor: 'rgba(0, 0, 0, 0.2)',
  popoverArrowBorderInverseColor: 'rgba(58, 63, 81, 0.75)',

  //
  // Table

  tableRowHoverBackgroundColor: 'rgba(255, 255, 255, 0.08)',

  //
  // Charts

  failedColors: ['#ffbeb2', '#feb4a6', '#fdab9b', '#fca290', '#fb9984', '#fa8f79', '#f9856e', '#f77b66', '#f5715d', '#f36754', '#f05c4d', '#ec5049', '#e74545', '#e13b42', '#da323f', '#d3293d', '#ca223c', '#c11a3b', '#b8163a', '#ae123a'],
  chartColorsDiversified: ['#90caf9', '#f4d166', '#ff8a65', '#ce93d8', '#80cba9', '#ffab91', '#8097ea', '#bcaaa4', '#a57583', '#e4e498', '#9e96af', '#c6ab81', '#6972c6', '#619fc6', '#81ad81', '#f48fb1', '#82afca', '#b5b071', '#8b959b', '#7ec0b4'],
  chartColors: ['#f4d166', '#f6c760', '#f8bc58', '#f8b252', '#f7a84a', '#f69e41', '#f49538', '#f38b2f', '#f28026', '#f0751e', '#eb6c1c', '#e4641e', '#de5d1f', '#d75521', '#cf4f22', '#c64a22', '#bc4623', '#b24223', '#a83e24', '#9e3a26']
};
